"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalize = void 0;
exports.normalize = (schema) => {
    if (schema === "number" || schema === "string") {
        return { type: schema };
    }
    else if (Array.isArray(schema) || schema.type === "object") {
        return normalizeObjectSchema(schema);
    }
    else if ("length" in schema) {
        return normalizeArraySchema(schema);
    }
    else {
        return { type: schema.type };
    }
};
const normalizeObjectSchema = (schema) => {
    if (Array.isArray(schema)) {
        return normalizeObjectSchema({
            type: "object",
            properties: schema,
        });
    }
    else {
        return {
            type: "object",
            properties: schema.properties.map(normalizePropertySchema),
        };
    }
};
const normalizePropertySchema = (schema) => {
    if (typeof schema === "string") {
        return { name: schema, value: exports.normalize("number") };
    }
    else if (Array.isArray(schema)) {
        const [propertyName, length, itemSchema] = schema;
        return {
            name: propertyName,
            value: {
                type: "array",
                length,
                items: exports.normalize(itemSchema || "number"),
            },
        };
    }
    else {
        const { name, value } = schema;
        return { name, value: exports.normalize(value) };
    }
};
const normalizeArraySchema = (schema) => {
    if (schema.type !== "array") {
        return normalizeArraySchema({
            type: "array",
            length: schema.length,
            items: schema.items
                ? exports.normalize(schema.items)
                : // TypeScript seems unable to select the subset of Schema
                    // that is correct here. It selects ArraySchema instead of
                    // NumberSchema | NormalStringSchema. Hence the cast.
                    exports.normalize({ type: schema.type }),
        });
    }
    else {
        return {
            type: "array",
            length: schema.length,
            items: exports.normalize(schema.items || "number"),
        };
    }
};
//# sourceMappingURL=normalize.js.map