"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseString = exports.parseNumber = exports.makeArrayParser = exports.makeObjectParser = void 0;
function makeObjectParser(propertyParsers) {
    return function parseObject(tokens, variables) {
        const result = {};
        const ownVariables = new Map(variables);
        for (const { name, value: parser } of propertyParsers) {
            const value = parser(tokens, ownVariables);
            result[name] = value;
            if (typeof value === "number") {
                // Looks like it could be a length for a future array, lets remember it
                if (ownVariables.has(name)) {
                    console.warn(`WARNING: overriding variable '${name}'`);
                }
                else if (variables.has(name)) {
                    console.warn(`WARNING: shadowing variable '${name}'`);
                }
                ownVariables.set(name, value);
            }
        }
        return result;
    };
}
exports.makeObjectParser = makeObjectParser;
function makeArrayParser(length, itemParser) {
    return function parseArray(tokens, variables) {
        const lengthValue = Number(variables.get(length));
        if (!Number.isSafeInteger(lengthValue) || lengthValue < 0) {
            throw new RangeError(`expected '${length}' to be a safe positive integer but found '${variables.get(length)}' which evaluated to '${lengthValue}'`);
        }
        const result = [];
        for (let i = 0; i < lengthValue; i++) {
            const value = itemParser(tokens, variables);
            result.push(value);
        }
        return result;
    };
}
exports.makeArrayParser = makeArrayParser;
exports.parseNumber = (tokens, context) => {
    const next = tokens.next();
    if (next.done) {
        throw new RangeError(`expected number but found no more tokens`);
    }
    const result = Number(next.value);
    if (Number.isNaN(result)) {
        throw new RangeError(`expected number but found '${next.value}' which evaluated to '${result}'`);
    }
    return result;
};
exports.parseString = (tokens, context) => {
    const next = tokens.next();
    if (next.done) {
        throw new RangeError(`expected string but found no more tokens`);
    }
    return next.value;
};
//# sourceMappingURL=parse.js.map