"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tap_1 = require("tap");
const stack_1 = require("./stack");
tap_1.test("empty stack", (t) => {
    const expected = [];
    const actual = stack_1.buildStack(null, []);
    t.deepEqual(actual, expected);
    t.end();
});
tap_1.test("one-level stack", (t) => {
    const expected = [{ path: [0], value: [0] }];
    const actual = stack_1.buildStack([0], [0]);
    t.deepEqual(actual, expected);
    t.end();
});
tap_1.test("five-level stack", (t) => {
    const root = [
        {
            prop: [
                0,
                1,
                2,
                3,
                { otherProp: ["array", "of", 4, "things"], unusedProp: 42 },
            ],
        },
    ];
    const expected = [
        {
            path: [1],
            value: root[0].prop[4].otherProp,
        },
        { path: ["otherProp", 1], value: root[0].prop[4] },
        { path: [4, "otherProp", 1], value: root[0].prop },
        {
            path: ["prop", 4, "otherProp", 1],
            value: root[0],
        },
        {
            path: [0, "prop", 4, "otherProp", 1],
            value: root,
        },
    ];
    const actual = stack_1.buildStack(root, [0, "prop", 4, "otherProp", 1]);
    t.deepEqual(actual, expected);
    t.end();
});
tap_1.test("stackToLines", (t) => {
    t.test("empty stack", (t) => {
        t.deepEqual(stack_1.stackToLines([]), []);
        t.end();
    });
    t.test("one-item stack", (t) => {
        const actual = stack_1.stackToLines([{ path: [], value: null }]);
        const expected = ["at $ in 'null'"];
        t.deepEqual(actual, expected);
        t.end();
    });
    t.test("five-item stack", (t) => {
        const actual = stack_1.stackToLines([
            { path: [], value: null },
            { path: [1, 2, 3], value: 1 },
            { path: ["1", "2", "3"], value: "null" },
            { path: ["one", "two", "three"], value: 908 },
            {
                path: [1000, "1000", "one thousand", "a fourth item just because"],
                value: true,
            },
        ]);
        const expected = [
            "at $ in 'null'",
            "at $[1][2][3] in '1'",
            "at $[1][2][3] in '\"null\"'",
            "at $.one.two.three in '908'",
            'at $[1000][1000]["one thousand"]["a fourth item just because"] in \'true\'',
        ];
        t.deepEqual(actual, expected);
        t.end();
    });
    t.end();
});
//# sourceMappingURL=stack.test.js.map